C
C=======================================================================
C
      SUBROUTINE AEDDIF_MI_MU(NPLAN,VAL,ZEM,IPHA,NAT2,COORD,NATYP,RHOK,
     1                        NATCLU,NFICHLEC,JFICH,NP,LE_MIN,LE_MAX)
C
C   This subroutine computes the AED formula in the spin-independent case
C        from a multiplet resolved initial core state L1. The 
C        intermediate state that gives its energy is L2 while the 
C        core hole that is filled in the process is noted LC. The 
C        multiplet is characterized by the integer angular momentum 
C        variables (L_MUL,S_MUL,J_MUL)
C
C   Alternatively, it can compute the AED amplitude for the APECS process.
C
C   The calculation is performed using a matrix inversion for the 
C           expression of the scattering path operator
C
C   The matrix inversion is performed using the LAPACK inversion 
C          routines for a general complex matrix
C
C                                          Last modified : 26 Apr 2013
C
      USE DIM_MOD

      USE ALGORITHM_MOD
      USE AMPLI_MOD
      USE APPROX_MOD
      USE COOR_MOD, NTCLU => NATCLU, NTP => NATYP
      USE DEBWAL_MOD
      USE DIRECT_A_MOD, DIRANA => DIRANA_A, ANADIR => ANADIR_A, 
     &                  RTHETA => RTHEXT_A, RPHI => RPHI_A,
     &                  THETAR => THETAR_A, PHIR => PHIR_A
      USE EXTREM_MOD
      USE FIXSCAN_A_MOD, N_FIXED => N_FIXED_A, N_SCAN => N_SCAN_A,
     &                   IPH_1 => IPH_1_A, FIX0 => FIX0_A, 
     &                   FIX1 => FIX1_A, SCAN0 => SCAN0_A, 
     &                   SCAN1 => SCAN1_A
      USE INFILES_MOD
      USE INUNITS_MOD
      USE INIT_J_MOD
      USE INIT_L_MOD
      USE INIT_M_MOD
      USE LIMAMA_MOD
      USE MOYEN_A_MOD, IMOY => IMOY_A, NDIR => NDIR_A,
     &                 ACCEPT => ACCEPT_A, ICHKDIR => ICHKDIR_A
      USE OUTFILES_MOD
      USE OUTUNITS_MOD
      USE PARCAL_A_MOD, NPHI => NPHI_A, NE => NE_A, 
     &                  NTHETA => NTHETA_A, NFTHET => NFTHET_A
      USE RESEAU_MOD
      USE SPIN_MOD
      USE TESTPB_MOD
      USE TESTS_MOD
      USE TL_AED_MOD, DLT => DLT_A, TL => TL_A, VK => VK_A,
     &                VK2 => VK2_A, IPOTC => IPOTC_A, ITL => ITL_A,
     &                LMAX => LMAX_A
      USE TYPCAL_A_MOD, IPHI => IPHI_A, IE => IE_A, ITHETA => ITHETA_A,
     &                  IFTHET => IFTHET_A, IMOD => IMOD_A,
     &                  I_CP => I_CP_A, I_EXT => I_EXT_A,
     &                  I_TEST => I_TEST_A
      USE TYPEM_MOD
      USE TYPEXP_MOD
      USE VALEX_A_MOD, PHI0 => PHI0_A, THETA0 => THETA0_A,
     &                 PHI1 => PHI1_A, THETA1 => THETA1_A
      USE VALIN_MOD, P0 => PHI0, T0 => THETA0, TM => THLUM, 
     &               PM => PHILUM, EM => ELUM
C
      COMPLEX IC,ONEC,ZEROC,PW(0:NDIF_M)
      COMPLEX TLT(0:NT_M,4,NATM,NE_M),RHOMI
      COMPLEX TAU(LINMAXA,LINFMAX,NATCLU_M)
      COMPLEX YLMR(0:NL_M,-NL_M:NL_M)
      COMPLEX YLME(0:NL_M,-NL_M:NL_M)
      COMPLEX R2,M_COUL(0:NL_M,-NL_M:NL_M,2,-LI_M:LI_M,2)
      COMPLEX SJDIR_1,SJDIF_1
      COMPLEX RHOK(0:NT_M,NATM,0:40,2,NSPIN2_M),COU
      COMPLEX SLJDIF,ATT_M,SLE_1
      COMPLEX SL0DIF,SMJDIF
C
      DIMENSION VAL(NATCLU_M),NATYP(NATM)
      DIMENSION EMET(3),COORD(3,NATCLU_M)
      DIMENSION R(NDIF_M),XR(NDIF_M),YR(NDIF_M),ZR(NDIF_M)
      DIMENSION JPOS(NDIF_M,3),JPA(NDIF_M)
C
      CHARACTER*7 STAT
      CHARACTER*24 INFILE
      CHARACTER*24 OUTFILE
C
      DATA PIS180 /0.017453/
      DATA EV,SMALL /13.60583,0.0001/
      DATA BOHR /0.529177/
C
      ALGO1='  '
      ALGO2='MI'
      ALGO3='  '
      ALGO4='  '
C
      IC=(0.,1.)
      ONEC=(1.,0.)
      ZEROC=(0.,0.)
      NSCAT=NATCLU-1
      ATTSE=1.
      ATTSJ=1.
      ZSURF=VAL(1)
C
      I_DIR=0
      NSET=1
      JEL=2
C
      IF(SPECTRO.EQ.'AED') THEN
        IOUT=IUO2
        OUTFILE=OUTFILE2
        STAT='UNKNOWN'
        IF(ABS(I_EXT).GE.1) THEN
          ISET=IUI6
          INFILE=INFILE6
        ENDIF
      ELSEIF(SPECTRO.EQ.'APC') THEN
        IOUT=IUSCR2
        OUTFILE='res/auger.amp'
        STAT='UNKNOWN'
        IF(ABS(I_EXT).GE.1) THEN
          ISET=IUI9
          INFILE=INFILE9
        ENDIF
      ENDIF
C
      LF1=LE_MIN
      LF2=LE_MAX
      ISTEP_LF=2
C
      IF((ISOM.EQ.0).OR.(JFICH.EQ.1)) THEN
        OPEN(UNIT=IOUT, FILE=OUTFILE, STATUS=STAT)
      ENDIF
C
C  Writing the headers in the output file
C
      CALL HEADERS(IOUT)
C
      IF((ISOM.EQ.0).OR.((ISOM.GT.0).AND.(JFICH.EQ.1))) THEN
        WRITE(IOUT,12) SPECTRO
        WRITE(IOUT,9) ISPIN,IDICHR,I_SO,ISFLIP,ICHKDIR,IPHI,ITHETA,IE,
     1                IPH_1,I_EXT
      ENDIF
C
      IF(ISOM.EQ.0) THEN
        WRITE(IOUT,79) NPLAN,NEMET,NTHETA,NPHI,NE
      ELSEIF((ISOM.NE.0).AND.(JFICH.EQ.1)) THEN
        WRITE(IOUT,11) NTHETA,NPHI,NE
      ENDIF
      IJK=0
C
C   Loop over the planes
C     
      DO JPLAN=1,NPLAN
       Z=VAL(JPLAN)
       IF((IPHA.EQ.1).OR.(IPHA.EQ.2)) THEN
         DZZEM=ABS(Z-ZEM)
         IF(DZZEM.LT.SMALL) GOTO 10
         GOTO 1
       ENDIF
 10    CONTINUE
C
C   Loop over the different absorbers in a given plane
C
       DO JEMET=1,NEMET
        CALL EMETT(JEMET,IEMET,Z,SYM_AT,NATYP,EMET,NTYPEM,
     1             JNEM,*4)
        GO TO 2                                                          
   4    IF((ISORT1.EQ.0).AND.(IPRINT.GT.0)) THEN          
          IF(I_TEST.NE.2) WRITE(IUO1,51) JPLAN,NTYPEM                                        
        ENDIF                                                             
        GO TO 3  
   2    IF((ABS(EMET(3)).GT.COUPUR).AND.(IBAS.EQ.1)) GOTO 5                 
        IF((ISORT1.EQ.0).AND.(IPRINT.GT.0)) THEN          
          IF(I_TEST.NE.2) THEN 
            WRITE(IUO1,52) JPLAN,EMET(1),EMET(2),EMET(3),NTYPEM  
          ENDIF               
        ENDIF
        IF(ISOM.EQ.1) NP=JPLAN 
        ZSURFE=VAL(1)-EMET(3) 
        JTE=IEMET(JEMET)     
        JATLEM=JNEM                   
C
C   Loop over the energies
C     
        DO JE=1,NE
         FMIN(0)=1.
         FMAX(0)=1.
         IF(I_TEST.NE.1) THEN                      
CST           VKR=REAL(VK(JE))
           VKR=ABS(VK(JE))
         ELSE
           VKR=1.
         ENDIF
CST         ECIN=VKR*VKR*BOHR*BOHR*EV/(A*A)+VINT
         ECIN=E0_A/(A*A)+VINT
         IF(I_TEST.NE.1) THEN                      
           CFM=2.*VKR
         ELSE
           CFM=1.
         ENDIF
         CALL LPM(ECIN,XLPM,*6)                                           
         XLPM1=XLPM/A                                                      
         GAMMA=1./(2.*XLPM1)                                               
         IF(IPOTC.EQ.0) THEN
           VK(JE)=VK(JE)+IC*GAMMA
         ENDIF
         IF(IPRINT.GT.0) WRITE(IUO1,56) A,XLPM1
         IF((IPRINT.GT.0).AND.(IBAS.EQ.1)) THEN
           IF(I_TEST.NE.2) WRITE(IUO1,57) COUPUR
         ENDIF
         IF((IDWSPH.EQ.1).AND.(ISPEED.EQ.1)) THEN
           IF(IDCM.GE.1) WRITE(IUO1,22)
           DO JAT=1,N_PROT
             IF(IDCM.EQ.0) THEN
               XK2UJ2=VK2(JE)*UJ2(JAT)
             ELSE
               XK2UJ2=VK2(JE)*UJ_SQ(JAT)
               WRITE(IUO1,23) JAT,UJ_SQ(JAT)*A*A
             ENDIF
             CALL DWSPH_A(JAT,JE,XK2UJ2,TLT,ISPEED)
             DO LAT=0,LMAX(JAT,JE)
               TL(LAT,1,JAT,JE)=TLT(LAT,1,JAT,JE)
             ENDDO
           ENDDO
         ENDIF
         IF(ABS(I_EXT).GE.1) THEN
           OPEN(UNIT=ISET, FILE=INFILE, STATUS='OLD')
           READ(ISET,13) I_DIR,NSET,N_DUM1
           READ(ISET,14) I_DUM1,N_DUM2,N_DUM3
         ENDIF
C
C   Initialization of TAU(INDJ,LINFMAX,JTYP)
C
         JATL=0
         DO JTYP=1,N_PROT
           NBTYP=NATYP(JTYP)
           LMJ=LMAX(JTYP,JE)
           DO JNUM=1,NBTYP
             JATL=JATL+1
             DO LE=LE_MIN,LE_MAX,2
               ILE=LE*LE+LE+1
               DO ME=-LE,LE
                 INDE=ILE+ME
                 DO LJ=0,LMJ
                   ILJ=LJ*LJ+LJ+1
                   DO MJ=-LJ,LJ 
                     INDJ=ILJ+MJ
                     TAU(INDJ,INDE,JATL)=ZEROC
                   ENDDO
                 ENDDO
               ENDDO
             ENDDO
           ENDDO
         ENDDO
C
C   Storage of the coupling matrix elements M_COUL 
C
         DO MC=-LI,LI
           DO ISC=1,2
             SC=FLOAT(ISC)-1.5
             DO LA=LE_MIN,LE_MAX,2
               DO MA=-LA,LA
                 DO ISA=1,2
                   SA=FLOAT(ISA)-1.5
                   CALL COUMAT_AM(LA,MA,SA,MC,SC,JTE,RHOK,COU)
                   M_COUL(LA,MA,ISA,MC,ISC)=COU
                 ENDDO
               ENDDO
             ENDDO
           ENDDO
         ENDDO
C
C   Matrix inversion for the calculation of TAU
C
        IF(I_TEST.EQ.2) GOTO 666
        CALL INV_MAT_MS_A(JE,TAU)
 666    CONTINUE
C
C    Calculation of the Auger Electron Diffraction formula
C
C 
C    Loop over the 'fixed' angle
C
  15     DO J_FIXED=1,N_FIXED
          IF(N_FIXED.GT.1) THEN
            IF(I_EXT.EQ.0) THEN
              FIX_STEP=(FIX1-FIX0)/FLOAT(N_FIXED-1)
              XINCRF=FLOAT(J_FIXED-1)*FIX_STEP
            ELSE
              XINCRF=0.
            ENDIF
          ELSEIF(N_FIXED.EQ.1) THEN
            XINCRF=0.
          ENDIF
          IF(ABS(I_EXT).GE.1) THEN
            READ(ISET,86) JSET,JLINE,THD,PHD
            IF(I_EXT.EQ.-1) BACKSPACE ISET
          ENDIF
          IF(IPH_1.EQ.1) THEN
             IF(I_EXT.EQ.0) THEN
               DPHI=PHI0+XINCRF
             ELSE
               DPHI=PHD
             ENDIF
             RPHI=DPHI*PIS180
             IF(IPRINT.GT.0) WRITE(IUO1,66) DPHI                                
          ELSE
             ISAUT=0
             IF(I_EXT.EQ.0) THEN
               DTHETA=THETA0+XINCRF
             ELSE
               DTHETA=THD
             ENDIF
             RTHETA=DTHETA*PIS180
             IF(ABS(DTHETA).GT.90.) ISAUT=ISAUT+1
             IF(I_EXT.GE.1) ISAUT=0
             IF(I_TEST.EQ.2)  ISAUT=0
             IF(ISAUT.GT.0) GOTO 8
             IF(IPRINT.GT.0) WRITE(IUO1,65) DTHETA                                     
             IF((IPRINT.GT.0).AND.(I_TEST.NE.2)) WRITE(IUO1,59)                                        
             IF((IPRINT.EQ.1).AND.(I_TEST.NE.2)) WRITE(IUO1,60)
C
C  THETA-dependent number of PHI points for stereographic 
C     representation (to obtain a uniform sampling density).
C     (Courtesy of J. Osterwalder - University of Zurich)
C
             IF(STEREO.EQ.'YES') THEN
               N_SCAN=INT((SCAN1-SCAN0)*SIN(RTHETA)/FIX_STEP+SMALL)+1
             ENDIF
C
          ENDIF
C
C    Loop over the scanned angle
C
          DO J_SCAN=1,N_SCAN
           IF(N_SCAN.GT.1) THEN
             XINCRS=FLOAT(J_SCAN-1)*(SCAN1-SCAN0)/FLOAT(N_SCAN-1)
           ELSEIF(N_SCAN.EQ.1) THEN
             XINCRS=0.
           ENDIF
           IF(I_EXT.EQ.-1) THEN
             READ(ISET,86) JSET,JLINE,THD,PHD
             BACKSPACE ISET
           ENDIF
           IF(IPH_1.EQ.1) THEN
             ISAUT=0
             IF(I_EXT.EQ.0) THEN
               DTHETA=THETA0+XINCRS
             ELSE
               DTHETA=THD
             ENDIF
             RTHETA=DTHETA*PIS180
             IF(ABS(DTHETA).GT.90.) ISAUT=ISAUT+1
             IF(I_EXT.GE.1) ISAUT=0
             IF(I_TEST.EQ.2)  ISAUT=0
             IF(ISAUT.GT.0) GOTO 8
             IF(IPRINT.GT.0) WRITE(IUO1,65) DTHETA                                  
             IF((IPRINT.GT.0).AND.(I_TEST.NE.2)) WRITE(IUO1,59)                                        
             IF((IPRINT.EQ.1).AND.(I_TEST.NE.2)) WRITE(IUO1,60)
           ELSE
             IF(I_EXT.EQ.0) THEN
               DPHI=PHI0+XINCRS
             ELSE
               DPHI=PHD
             ENDIF
             RPHI=DPHI*PIS180
             IF(IPRINT.GT.0) WRITE(IUO1,66) DPHI                                  
           ENDIF 
C
C  Loop over the sets of directions to average over (for gaussian average)
C                                    
C
           SSETDIR_1=0.
           SSETDIF_1=0.
C
           IF(I_EXT.EQ.-1) THEN
             JREF=INT(NSET)/2+1
           ELSE
             JREF=1
           ENDIF
C
           DO J_SET=1,NSET
           IF(I_EXT.EQ.-1) THEN
             READ(ISET,86) JSET,JLINE,THD,PHD,W
             DTHETA=THD
             DPHI=PHD
             RTHETA=DTHETA*PIS180
             RPHI=DPHI*PIS180
           ELSE
             W=1.
           ENDIF
C
           IF(I_EXT.EQ.-1) PRINT 89
C                                    
           CALL DIRAN(VINT,ECIN,JEL)
           IF(J_SET.EQ.JREF) THEN
             DTHETAP=DTHETA
             DPHIP=DPHI
           ENDIF
C
           IF(I_EXT.EQ.-1) THEN
             WRITE(IUO1,88) DTHETA,DPHI
           ENDIF
C
           WRITE(IUO1,61) (DIRANA(J,1),J=1,3)
C
           SRDIF_1=0.
           SRDIR_1=0.
C
C    Loop over the different directions of the analyzer contained in a cone
C
          DO JDIR=1,NDIR
            IF(IATTS.EQ.1) THEN
              ATTSE=EXP(-ZSURFE*GAMMA/DIRANA(3,JDIR))
            ENDIF
C
            SSCDIR_1=0.
            SSCDIF_1=0.
C
C    Loop over the equiprobable quantum numbers MC,SC and SA 
C         corresponding respectively to the core hole (MC and spin SC)
C         and to the outgoing Auger electron (SA). The sum over the 
C         equiprobable azimuthal quantum number MJ of the multiplet 
C         configuration is suppressed here as, because of the selection 
C         rules, one has MJ = MA + MC + SA + SC
C
            LME=LMAX(1,JE)
            CALL HARSPH(NL_M,THETAR(JDIR),PHIR(JDIR),YLME,LME)
C
            DO ISC=1,2
             SC=FLOAT(ISC)-1.5
C
             SMCDIR_1=0.
             SMCDIF_1=0.
C
             DO MC=-LI,LI
C
              SSADIR_1=0.
              SSADIF_1=0.
C
              DO ISA=1,2
               SA=FLOAT(ISA)-1.5
C
                SMJMDIR_1=0.
                SMJMDIF_1=0.
C
                DO MJM=-J_MUL,J_MUL
C
                 SJDIR_1=ZEROC
                 SJDIF_1=ZEROC
C
C    Calculation of the direct emission (used a a reference for the output)
C
                 DO L_E=LE_MIN,LE_MAX,2
                  ILE=L_E*L_E+L_E+1
                  IF(ISPEED.EQ.1) THEN
                    R2=TL(L_E,1,1,JE)
                  ELSE
                    R2=TLT(L_E,1,1,JE)
                  ENDIF
                  M_E=MJM-MC-ISA-ISC+3
                  IF(ABS(M_E).GT.L_E) GOTO 444
                  INDE=ILE+M_E
                  SJDIR_1=SJDIR_1+YLME(L_E,M_E)*ATTSE*
     1                            M_COUL(L_E,M_E,ISA,MC,ISC)*R2
C                  
C    Contribution of the absorber to TAU (initialization of SJDIF)
C
                  IF(I_TEST.EQ.2) GOTO 444
                  SL0DIF=ZEROC
                  DO L0=0,LME
                    IL0=L0*L0+L0+1
                    SL0DIF=SL0DIF+YLME(L0,0)*TAU(IL0,INDE,1)
                    DO M0=1,L0
                     IND01=IL0+M0
                     IND02=IL0-M0
                     SL0DIF=SL0DIF+(YLME(L0,M0)*
     1                              TAU(IND01,INDE,1)+
     2                              YLME(L0,-M0)*
     3                              TAU(IND02,INDE,1))
                    ENDDO
                  ENDDO

                  SJDIF_1=SJDIF_1+SL0DIF*M_COUL(L_E,M_E,ISA,MC,ISC)
 444              CONTINUE
                 ENDDO
                 SJDIF_1=SJDIF_1*ATTSE
C
C    Loop over the last atom J encountered by the photoelectron 
C                  before escaping the solid
C
                 IF(I_TEST.EQ.2) GOTO 111
                 DO JTYP=2,N_PROT
                  NBTYP=NATYP(JTYP)
                  LMJ=LMAX(JTYP,JE)
                  DO JNUM=1,NBTYP
                   JATL=NCORR(JNUM,JTYP)
                   XOJ=SYM_AT(1,JATL)-EMET(1)
                   YOJ=SYM_AT(2,JATL)-EMET(2)
                   ZOJ=SYM_AT(3,JATL)-EMET(3)
                   ROJ=SQRT(XOJ*XOJ+YOJ*YOJ+ZOJ*ZOJ)
                   ZSURFJ=VAL(1)-SYM_AT(3,JATL)
                   CALL HARSPH(NL_M,THETAR(JDIR),PHIR(JDIR),YLMR,
     1                         LMJ)
                   IF(IATTS.EQ.1) THEN
                     ATTSJ=EXP(-ZSURFJ*GAMMA/DIRANA(3,JDIR))
                   ENDIF
                   CSTHJR=(XOJ*DIRANA(1,JDIR)+YOJ*DIRANA(2,JDIR)+
     1                     ZOJ*DIRANA(3,JDIR))/ROJ
                   IF((IDWSPH.EQ.1).AND.(ISPEED.EQ.1)) GOTO 78
                   CTROIS1=ZOJ/ROJ
                   IF(CTROIS1.GT.1.)  THEN
                     CTROIS1=1.
                   ELSEIF(CTROIS1.LT.-1.) THEN
                     CTROIS1=-1.
                   ENDIF
                   IF(IDCM.GE.1) THEN
                     UJ2(JTYP)=UJ_SQ(JTYP)
                   ENDIF
                   IF(ABS(ZSURFJ).LE.SMALL) THEN 
                     IF(ABS(CSTHJR-1.).GT.SMALL) THEN
                       CSKZ2J=(DIRANA(3,JDIR)-CTROIS1)*
     1                        (DIRANA(3,JDIR)-CTROIS1)/(2.
     2                         -2.*CSTHJR)
                     ELSE
                       CSKZ2J=1.
                     ENDIF
                     UJJ=UJ2(JTYP)*(1.+CSKZ2J*(RSJ-1.))
                   ELSE
                     UJJ=UJ2(JTYP)
                   ENDIF
                   IF((ISPEED.EQ.0).AND.(IDWSPH.EQ.1)) THEN
                     XK2UJ2=VK2(JE)*UJJ
                     CALL DWSPH_A(JTYP,JE,XK2UJ2,TLT,ISPEED)
                   ENDIF
 78                IF(IDWSPH.EQ.1) THEN
                     DWTER=1.
                   ELSE
                     DWTER=EXP(-VK2(JE)*UJJ*(1.-CSTHJR))
                   ENDIF
                   IF(JATL.EQ.JATLEM) THEN
                     ATT_M=ATTSE*DWTER
                   ELSE
                     ATT_M=ATTSJ*DWTER*CEXP(-IC*VK(JE)*ROJ*CSTHJR)
                   ENDIF
C
                   SLE_1=ZEROC
                   DO L_E=LE_MIN,LE_MAX,2
                     ILE=L_E*L_E+L_E+1
                     M_E=MJM-MC-ISA-ISC+3
                     IF(ABS(M_E).GT.L_E) GOTO 555
                     INDE=ILE+M_E
                     SLJDIF=ZEROC
                     DO LJ=0,LMJ
                       ILJ=LJ*LJ+LJ+1
                       SMJDIF=YLMR(LJ,0)*TAU(ILJ,INDE,JATL)
                       IF(LJ.GT.0) THEN
                         DO MJ=1,LJ
                           INDJ1=ILJ+MJ
                           INDJ2=ILJ-MJ
                           SMJDIF=SMJDIF+(YLMR(LJ,MJ)*
     1                                    TAU(INDJ1,INDE,JATL)+
     2                                    YLMR(LJ,-MJ)*
     3                                    TAU(INDJ2,INDE,JATL))
                         ENDDO
                       ENDIF  
                       SLJDIF=SLJDIF+SMJDIF
                     ENDDO
                     SLE_1=SLE_1+SLJDIF*M_COUL(L_E,M_E,ISA,MC,ISC)
  555                CONTINUE
                   ENDDO
                   SJDIF_1=SJDIF_1+SLE_1*ATT_M
C
C     End of the loops over the last atom J 
C
                  ENDDO
                 ENDDO
C
C     Writing the amplitudes in file IOUT for APECS
C
 111             IF(SPECTRO.EQ.'APC') THEN
                   IF(I_TEST.EQ.2) SJDIF_1=SJDIR_1
                   WRITE(IOUT,87) JFICH,JPLAN,JEMET,JE,J_FIXED,J_SCAN,
     1                            JDIR,ISC,MC,ISA,MJM,SJDIR_1,SJDIF_1
                 ELSE
C
C     Computing the square modulus
C
                   SSADIF_1=SSADIF_1+CABS(SJDIF_1)*CABS(SJDIF_1)
                   SSADIR_1=SSADIR_1+CABS(SJDIR_1)*CABS(SJDIR_1)
C
                 ENDIF
C
C     End of the loop over MJM
C
                ENDDO
C
                SMJMDIF_1=SMJMDIF_1+SSADIF_1           
                SMJMDIR_1=SMJMDIR_1+SSADIR_1           
C
C     End of the loop over SA
C
              ENDDO
C
              SMCDIF_1=SMCDIF_1+SMJMDIF_1           
              SMCDIR_1=SMCDIR_1+SMJMDIR_1           
C
C     End of the loop over MC
C
             ENDDO
C
             SSCDIF_1=SSCDIF_1+SMCDIF_1           
             SSCDIR_1=SSCDIR_1+SMCDIR_1           
C
C     End of the loop over SC
C
            ENDDO
C
            IF(SPECTRO.EQ.'APC') GOTO 220
            SRDIR_1=SRDIR_1+SSCDIR_1*VKR*CFM/NDIR
            SRDIF_1=SRDIF_1+SSCDIF_1*VKR*CFM/NDIR
 220        CONTINUE
C
C     End of the loop on the directions of the analyzer
C
           ENDDO
C
            IF(SPECTRO.EQ.'APC') GOTO 221
            SSETDIR_1=SSETDIR_1+SRDIR_1*W
            SSETDIF_1=SSETDIF_1+SRDIF_1*W
            IF(ICHKDIR.EQ.2) THEN
              IF(JSET.EQ.JREF) THEN
                SSET2DIR_1=SRDIR_1
                SSET2DIF_1=SRDIF_1
              ENDIF
            ENDIF
 221        CONTINUE
C
C     End of the loop on the set averaging 
C
           ENDDO
C
            IF(SPECTRO.EQ.'APC') GOTO 222
            IF(ISOM.EQ.2) THEN
              WRITE(IOUT,67) JPLAN,JFICH,DTHETAP,DPHIP,ECIN,
     1                       SSETDIR_1,SSETDIF_1
              IF(ICHKDIR.EQ.2) THEN
               WRITE(IUO2,67) JPLAN,JFICH,DTHETAP,DPHIP,ECIN,
     1                        SSET2DIR_1,SSET2DIF_1 
              ENDIF
            ELSE
              WRITE(IOUT,67) JPLAN,JEMET,DTHETAP,DPHIP,ECIN,
     1                       SSETDIR_1,SSETDIF_1 
              IF(ICHKDIR.EQ.2) THEN
               WRITE(IUO2,67) JPLAN,JEMET,DTHETAP,DPHIP,ECIN,
     1                        SSET2DIR_1,SSET2DIF_1 
              ENDIF
            ENDIF
 222        CONTINUE
C
C     End of the loop on the scanned angle
C
          ENDDO
C
   8      CONTINUE
C
C     End of the loop on the fixed angle
C
         ENDDO
C
C     End of the loop on the energy
C
         CLOSE(ISET)
        ENDDO
C
   3    CONTINUE
C
C     End of the loop on the emitters
C
       ENDDO
C
       GO TO 1                                                        
   5   IPLAN=JPLAN-1                                                  
       IJK=IJK+1                                                      
       IF((IJK.EQ.1).AND.(IPRINT.GT.0)) THEN          
         IF(I_TEST.NE.2) WRITE(IUO1,54) IPLAN                                            
       ENDIF                                                          
   1   CONTINUE
C
C     End of the loop on the planes
C
      ENDDO
C
      IF(ABS(I_EXT).GE.1) CLOSE(ISET)
      IF((ISOM.EQ.0).OR.(JFICH.EQ.NFICHLEC)) WRITE(IOUT,*)
      IF(SPECTRO.EQ.'APC') CLOSE(IOUT)
      IF(SPECTRO.EQ.'APC') GOTO 7
c      IF(((NEMET.GT.1).OR.(NPLAN.GT.1)).AND.(ISOM.EQ.0)) THEN
      IF(((NEMET.GT.1).OR.(NPLAN.GT.0)).AND.(ISOM.EQ.0)) THEN
        NP=0
        CALL TREAT_AED(ISOM,NFICHLEC,JFICH,NP)
      ENDIF
      IF(I_EXT.EQ.2) THEN
         CALL WEIGHT_SUM(ISOM,I_EXT,0,1)
      ENDIF
      GOTO 7
   6  WRITE(IUO1,55)
C
   9  FORMAT(9(2X,I1),2X,I2)  
  11  FORMAT(I4,2X,I4,2X,I4)
  12  FORMAT(2X,A3)
  13  FORMAT(6X,I1,1X,I3,2X,I4)
  14  FORMAT(6X,I1,1X,I3,3X,I3)
  22  FORMAT(16X,'INTERNAL CALCULATION OF MEAN SQUARE DISPLACEMENTS',/,
     1       25X,' BY DEBYE UNCORRELATED MODEL:',/)
  23  FORMAT(21X,'ATOM TYPE ',I5,'  MSD = ',F8.6,' ANG**2')
  51  FORMAT(/////,2X,'******* PLANE NUMBER ',I3,' DOES NOT CONTAIN ',
     *'ANY ABSORBER OF TYPE ',I2,' *******')                                   
  52  FORMAT(/////,2X,'******* PLANE NUMBER ',I3,' POSITION OF ',
     1'THE ABSORBER : (',F6.3,',',F6.3,',',F6.3,') *******',/,2X,
     2'******* ',19X,'THIS ABSORBER IS OF TYPE ',I2,20X,' *******')          
  53  FORMAT(//,2X,'ORDER ',I2,'  TOTAL NUMBER OF PATHS     : ',F15.1,
     1             /,10X,'  EFFECTIVE NUMBER OF PATHS : ',F15.1,
     2             /,10X,'  MINIMAL INTENSITY         : ',E12.6,
     3             2X,'No OF THE PATH : ',F15.1,                         
     4             /,10X,'  MAXIMAL INTENSITY         : ',E12.6,
     5             2X,'No OF THE PATH : ',F15.1)                         
  54  FORMAT(//,7X,'DUE TO THE SIZE OF THE CLUSTER, THE SUMMATION',  
     *' HAS BEEN TRUNCATED TO THE ',I2,' TH PLANE') 
  55  FORMAT(///,12X,' <<<<<<<<<<  THIS VALUE OF ILPM IS NOT',
     *'AVAILABLE  >>>>>>>>>>')                                            
  56  FORMAT(4X,'LATTICE PARAMETER A = ',F6.3,' ANGSTROEMS',4X,      
     *'MEAN FREE PATH = ',F6.3,' * A',//)        
  57  FORMAT(25X,'CLUSTER RADIUS = ',F6.3,' *A')                  
  58  FORMAT(//,2X,'ORDER ',I2,'  TOTAL NUMBER OF PATHS     : ',I10,
     1             /,10X,'  EFFECTIVE NUMBER OF PATHS : ',I10,                
     2             /,10X,'  MINIMAL INTENSITY         : ',E12.6,
     3             2X,'No OF THE PATH : ',I10,                         
     4             /,10X,'  MAXIMAL INTENSITY         : ',E12.6,             
     5             2X,'No OF THE PATH : ',I10)                         
  59  FORMAT(//,15X,'THE SCATTERING DIRECTION IS GIVEN INSIDE ',   
     *'THE CRYSTAL')
  60  FORMAT(7X,'THE POSITIONS OF THE ATOMS ARE GIVEN WITH RESPECT ', 
     *'TO THE ABSORBER')                                                  
  61  FORMAT(///,4X,'..........  DIRECTION OF THE DETECTOR      : (',
     1      F6.3,',',F6.3,',',F6.3,')  ..........')                                       
  65  FORMAT(////,3X,'++++++++++++++++++',9X,     
     *'THETA = ',F6.2,' DEGREES',9X,'++++++++',      
     *'++++++++++',///)                                                  
  66  FORMAT(////,3X,'++++++++++++++++++',9X,     
     *'PHI = ',F6.2,' DEGREES',9X,'++++++++++',      
     *'++++++++++',///)                                                  
  67  FORMAT(2X,I3,2X,I2,2X,F6.2,2X,F6.2,2X,F8.2,2X,E12.6,
     1       2X,E12.6)
  68  FORMAT(10X,'  CUT-OFF INTENSITY       : ',E12.6)
  69  FORMAT(9X,I2,2X,E12.6,7X,E12.6,1X,F6.3,1X,10(I3,2X))
  70  FORMAT(2X,I2,2X,I10,7X,E12.6,2X,F6.3,7X,I2,7X,10(I3,2X))
  71  FORMAT(//,1X,'JDIF',4X,'No OF THE PATH',2X,
     1       'INTENSITY',3X,'LENGTH',4X,'ABSORBER',2X,
     2       'ORDER OF THE SCATTERERS',/)
  74  FORMAT(10X,'<===== NUMBER OF PATHS TOO LARGE FOR PRINTING ',
     1       '=====>')
  76  FORMAT(2X,I2,2X,E12.6,7X,E12.6,2X,F6.3,7X,I2,7X,10(I3,2X))
  77  FORMAT('   ')
  79  FORMAT(2X,I3,2X,I2,2X,I4,2X,I4,2X,I4)
  80  FORMAT(///) 
  81  FORMAT(//,1X,'RANK',1X,'ORDER',4X,'No PATH',3X,
     1       'INTENSITY',3X,'LENGTH',4X,'ABS',3X,
     2       'ORDER OF THE SCATTERERS',/)
  82  FORMAT(I3,4X,I2,1X,E12.6,3X,E12.6,2X,F6.3,4X,I2,4X,10(I3,1X))
  83  FORMAT(I3,4X,I2,1X,I10,3X,E12.6,2X,F6.3,4X,I2,4X,10(I3,1X))
  84  FORMAT(/////,18X,'THE ',I3,' MORE INTENSE PATHS BY DECREASING',
     1      ' ORDER :',/,24X,'(THE LENGTH IS GIVEN IN UNITS ',
     2      'OF A)')
  85  FORMAT(/////,25X,' PATHS USED IN THE CALCULATION : ',
     1       /,24X,'(THE LENGTH IS GIVEN IN UNITS OF A)')
  86  FORMAT(2X,I3,1X,I4,5X,F8.3,3X,F8.3,3X,E12.6)
  87  FORMAT(2X,I2,2X,I3,2X,I2,2X,I3,2X,I3,2X,I3,2X,I2,2X,I2,2X,I2,
     1       2X,I2,2X,I2,2X,E12.6,2X,E12.6,2X,E12.6,2X,E12.6)
  88  FORMAT(/,19X,'TILTED THETA =',F6.2,5X,'TILTED PHI =', 
     1         F6.2) 
  89  FORMAT(/,4X,'..........................................',
     1         '.....................................')    
C
   7  RETURN
C
      END
