C
C=======================================================================
C
      SUBROUTINE COUMAT_AM(LA,MA,SA,MC,SC,JE,RHOK_A,MATRIX_AM)
C
C  This routine calculates the multiplet-resolved spin-independent
C   Coulomb matrix elements occuring in the Auger process. They 
C   are stored in MATRIX_AM. The multiplet component is characterized 
C   by the quantum numbers (L,S,J) which are read from the input 
C   data file.
C
C  Here, the conventions are (direct process D):
C
C        (LC,MC)  : core hole filled by intermediate electron 
C        (L1,M1)  : Auger electron before excitation
C        (L2,M2)  : intermediate electron that fills the core hole
C        (LA,MA)  : Auger electron after excitation
C
C  In the exchange process E, the roles of (L1,M1) and (L2,M2) 
C    are interchanged.
C
C  Note that the Clebsch-Gordan corresponding to the spin-orbit 
C    resolved core state is not included in the formula here. This 
C    is because in APECS, it appears also in the dipole matrix 
C    element and it is therefore useless to calculate it twice.
C    Therefore, it must be implemented into the cross-section 
C    subroutine.
C
C  The factor i**LA comes from the particular normalization used 
C    in the phagen code
C
C                                        Last modified :  8 Dec 2008
C
      USE DIM_MOD
C
      USE C_G_M_MOD
      USE INIT_A_MOD, LC => LI_C, L2 => LI_I, L1 => LI_A
      USE TYPCAL_A_MOD, I1 => IPHI_A, I2 => IE_A, I3 => ITHETA_A,
     1                  I4 => IFTHET_A, I5 => IMOD_A, I6 => I_CP_A,
     2                  I7 => I_EXT_A, I_TEST => I_TEST_A
      USE INIT_M_MOD
C
      COMPLEX RHOK_A(0:NT_M,NATM,0:40,2,NSPIN2_M)
      COMPLEX ZEROC,ONEC,MATRIX_AM
      COMPLEX SUM_LB,SUM_M1,IC,IL
C
      REAL*4 CG1(0:N_GAUNT),CG2(0:N_GAUNT)
      REAL*4 GNT1(0:N_GAUNT),GNT2(0:N_GAUNT),GNT3(0:N_GAUNT)
      REAL*4 GNT4(0:N_GAUNT)
C
      REAL*8 ZEROD
C
      DATA PI4,ONEOSQ2,HALF /12.566371,0.707107,0.5/
C
      ZEROC=(0.,0.)
      ONEC=(1.,0.)
      IC=(0.,1.)
      ZEROD=0.D0
C
      IF(I_TEST.EQ.1) GOTO 2
C
      IF(MOD(LA,4).EQ.0) THEN
        IL=ONEC
      ELSEIF(MOD(LA,4).EQ.1) THEN
        IL=IC
      ELSEIF(MOD(LA,4).EQ.2) THEN
        IL=-ONEC
      ELSEIF(MOD(LA,4).EQ.3) THEN
        IL=-IC
      ENDIF
C
      IF(I_SHELL.EQ.0) THEN
        COEF1=ONEOSQ2*PI4
      ELSEIF(I_SHELL.EQ.1) THEN
        COEF1=HALF*PI4
      ENDIF
C
      IF(MOD(S_MUL,2).EQ.0) THEN
        SIGN1=1.
      ELSE
        SIGN1=-1.
      ENDIF
C
C   Values of MJ, ML and MS given by the Clebsch-Gordan
C
      ML=MA+MC
      MS=INT(SA+SC+0.0001)
      MJ=ML+MS
C
C  Storage indices for the spin Clebsch-Gordan :
C
C               ISA(C) = 1 for -1/2 and 2 for 1/2
C               IS = 1 for S_MUL=0 and 2 for S_MUL=1
C
      IS=S_MUL+1
      ISA=INT(SA+1.5001)
      ISC=INT(SC+1.5001)
C
C  Bounds of the sum over LB
C
      LB_MAX_D=MIN(L1+LA,L2+LC)
      LB_MIN_D=MAX(ABS(L1-LA),ABS(L2-LC))
      LB_MAX_E=MIN(L2+LA,L1+LC)
      LB_MIN_E=MAX(ABS(L2-LA),ABS(L1-LC))
      LB_MIN=MIN(LB_MIN_D,LB_MIN_E)
      LB_MAX=MAX(LB_MAX_D,LB_MAX_E)
C
      N_CG=2
      CALL N_J(DFLOAT(L_MUL),DFLOAT(ML),DFLOAT(S_MUL),DFLOAT(MS),
     1         ZEROD,CG1,I_INT1,N_CG)
C
      SUM_M1=ZEROC
      DO M1=-L1,L1
        M2=ML-M1
C
        CALL N_J(DFLOAT(L1),DFLOAT(M1),DFLOAT(L2),DFLOAT(ML-M1),
     1           ZEROD,CG2,I_INT2,N_CG)
        CALL GAUNT(L1,M1,LA,MA,GNT1)      
        CALL GAUNT(LC,MC,L2,M2,GNT2)      
        CALL GAUNT(L2,M2,LA,MA,GNT3)      
        CALL GAUNT(LC,MC,L1,M1,GNT4)
C      
        SUM_LB=ZEROC
        DO LB=LB_MIN,LB_MAX
          SUM_LB=SUM_LB+(RHOK_A(LA,JE,LB,1,1)*GNT1(LB)*GNT2(LB)+
     1                   RHOK_A(LA,JE,LB,2,1)*GNT3(LB)*GNT4(LB)*
     2                   SIGN1)/FLOAT(LB+LB+1)
        ENDDO
        SUM_M1=SUM_M1+SUM_LB*CG2(L_MUL)
      ENDDO
C
      MATRIX_AM=SUM_M1*CG1(J_MUL)*CG_S(ISA,ISC,IS)*COEF1*IL
C
      GOTO 1
C
   2  MATRIX_AM=ONEC
C
   1  RETURN                             
C
      END
